@@ -1,12 +1,13 @@
 package App::CharmKit::Logging;
-$App::CharmKit::Logging::VERSION = '0.011';
+$App::CharmKit::Logging::VERSION = '0.013';
 # ABSTRACT: reporting utilities
 
 
+use Data::Dumper;
 use App::CharmKit::Sys qw/execute/;
 use Exporter qw/import/;
 
-our @EXPORT = qw/log/;
+our @EXPORT = qw/log prettyLog/;
 
 sub log {
     my $message = shift;
@@ -20,6 +21,11 @@ sub log {
     execute($cmd);
 }
 
+sub prettyLog {
+    my $obj = shift;
+    print Dumper($obj);
+}
+
 1;
 
 __END__
@@ -34,7 +40,7 @@ App::CharmKit::Logging - reporting utilities
 
 =head1 VERSION
 
-version 0.011
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -58,6 +64,10 @@ Reporting utilities
 
 Utilizies juju-log for any additional logging
 
+=head2 prettyLog(object)
+
+Dumps the perl data structure into something readable
+
 =head1 AUTHOR
 
 Adam Stokes <adamjs@cpan.org>
