@@ -1,5 +1,5 @@
 package App::CharmKit::Role::Lint;
-$App::CharmKit::Role::Lint::VERSION = '0.011';
+$App::CharmKit::Role::Lint::VERSION = '0.013';
 # ABSTRACT: charm linter
 
 use strict;
@@ -7,6 +7,7 @@ use warnings;
 use YAML::Tiny;
 use Path::Tiny;
 use File::ShareDir qw(dist_file);
+use DDP;
 
 use Class::Tiny {
     errors => {
@@ -22,6 +23,11 @@ use Class::Tiny {
             message => 'Missing optional configuration item',
             level   => 'WARNING'
         },
+        ERR_CONFIG_SYNTAX => {
+            message =>
+              'Issue with an item, could be duplicate or a conflicting key',
+            level => 'FATAL'
+        },
         ERR_NO_REQUIRES => {
             message => 'No requires set for charm relations',
             level   => 'WARNING'
@@ -39,7 +45,7 @@ use Class::Tiny {
             level   => 'INFO'
         },
         ERR_EXISTS => {
-            message => 'File does not exist',
+            message => 'Required file does not exist',
             level   => 'FATAL'
         },
         ERR_EMPTY => {
@@ -57,13 +63,85 @@ sub parse {
     # Check attributes
     my $rules = $self->rules->[0];
     foreach my $meta (@{$rules->{files}}) {
-        $self->validate($meta);
+        $self->validate_attributes($meta);
+        if ($meta->{name} =~ /^metadata\.yaml/) {
+            $self->validate_metadata($meta);
+        }
+        if ($meta->{name} =~ /^config\.yaml/) {
+            $self->validate_configdata($meta);
+        }
+    }
+    foreach my $hook (@{$rules->{hooks}}) {
+        $self->validate_hook($hook);
+    }
+}
+
+sub validate_configdata {
+    my ($self, $configdata) = @_;
+    my $config_on_disk = YAML::Tiny->read($configdata->{name})->[0];
+    my $filepath       = path($configdata->{name});
+    $self->check_error(sprintf("%s:options", $configdata->{name}),
+        'ERR_REQUIRED_CONFIG_ITEM')
+      unless defined($config_on_disk->{options});
+
+    foreach my $option (keys %{$config_on_disk->{options}}) {
+        my $check_opt = $config_on_disk->{options}->{$option};
+        if (   !defined($check_opt->{type})
+            || !defined($check_opt->{description})
+            || !defined($check_opt->{default}))
+        {
+            $self->check_error(sprintf("%s:%s", $filepath, $option),
+                'ERR_REQUIRED_CONFIG_ITEM');
+        }
     }
 }
 
 
+sub validate_metadata {
+    my ($self, $metadata) = @_;
+    my $meta_on_disk = YAML::Tiny->read($metadata->{name})->[0];
+    my $filepath     = path($metadata->{name});
+    foreach my $metakey (@{$metadata->{known_meta_keys}}) {
+        if ($metakey =~ /name|summary|description/
+            && !defined($meta_on_disk->{$metakey}))
+        {
+            $self->check_error(sprintf("%s:%s", $metadata->{name}, $metakey),
+                'ERR_REQUIRED_CONFIG_ITEM');
+        }
+        elsif (!defined($meta_on_disk->{$metakey})) {
+            $self->check_error(sprintf("%s:%s", $metadata->{name}, $metakey),
+                'ERR_CONFIG_ITEM');
+        }
+    }
+    foreach my $re (@{$metadata->{parse}}) {
 
-sub validate {
+        # Dont parse if file doesn't exist and wasn't required
+        next if !$filepath->exists;
+        my $input  = $filepath->slurp_utf8;
+        my $search = $re->{pattern};
+        if ($input !~ /$search/m) {
+            $self->check_error($filepath, $re->{error});
+        }
+    }
+}
+
+
+sub validate_hook {
+    my ($self, $hookmeta) = @_;
+    my $filepath = path('hooks')->child($hookmeta->{name});
+    my $name     = $filepath->stringify;
+    foreach my $attr (@{$hookmeta->{attributes}}) {
+        if ($attr =~ /EXISTS/) {
+            $self->check_error($name, 'ERR_EXISTS') unless $filepath->exists;
+        }
+        if ($attr =~ /NOT_EMPTY/ && -z $filepath) {
+            $self->check_error($name, 'ERR_EMPTY');
+        }
+    }
+}
+
+
+sub validate_attributes {
     my ($self, $filemeta) = @_;
     my $filepath = path($filemeta->{name});
     my $name     = $filemeta->{name};
@@ -86,16 +164,6 @@ sub validate {
         }
     }
 
-    foreach my $re (@{$filemeta->{parse}}) {
-
-        # Dont parse if file doesn't exist and wasn't required
-        next if !$filepath->exists;
-        my $input  = $filepath->slurp_utf8;
-        my $search = $re->{pattern};
-        if ($input !~ /$search/m) {
-            $self->check_error($name, $re->{error});
-        }
-    }
 }
 
 sub check_error {
@@ -130,7 +198,7 @@ App::CharmKit::Role::Lint - charm linter
 
 =head1 VERSION
 
-version 0.011
+version 0.013
 
 =head1 SYNOPSIS
 
@@ -201,7 +269,19 @@ Stores whether or not a fatal error was found
 
 Parses charm
 
-=head2 validate(HASHREF filemeta)
+=head2 validate_configdata(HASHREF configdata)
+
+Validates B<config.yaml>
+
+=head2 validate_metadata(HASHREF metadata)
+
+Validates B<metadata.yaml>
+
+=head2 validate_hook(HASHREF hookmeta)
+
+Validates charm hooks
+
+=head2 validate_attributes(HASHREF filemeta)
 
 Performs validation of file based on available attribute
 
